==> bash-unit_2.3.2.orig.tar.gz: bash_unit-2.3.2/CONTRIBUTING.md <==
**bash unit testing enterprise edition framework for professionals ![bash_unit](img/bu_50.png)**

If you like bash_unit and want to contribute, you can do so in one of the
following ways (order might matter).

# Spread the word

Talking about bash_unit is a very welcomed contribution.

Share your success with bash_unit on your blog, twitter, stackoverflow...

Nice words to share your experience with bash_unit is always appreciated.
If you want to say something nice about bash_unit but can not think of a 
place for that right now, just add a comment to
[issue #37](https://github.com/pgrange/bash_unit/issues/37).

Starring the project is also appreciated.

# Suggest improvements

When you see something that is not working with bash_unit, or if you feel
something is missing, open an
[issue](https://github.com/pgrange/bash_unit/issues).

Opening issues helps improving bash_unit.

# Contribute code

If you use a tool like bash_unit, odds are high that you already heard
about software development. Just code the improvement you have in mind
and create a pull-request.

You can contribute with new features you think are missing but you can
also find inspiration with the
[open issues](https://github.com/pgrange/bash_unit/issues) of bash_unit.

See [how to contribute code](CONTRIBUTING_CODE.md).

# Donate

bash_unit is free software I develop during my (not so) free time. If you feel
bash_unit is helpful enough to you that you want to compensate for some of
the time spent developing or promoting it, you can contribute with your money
on liberapay:

[![liberapay](https://liberapay.com/assets/widgets/donate.svg)](https://liberapay.com/bash_unit/donate)

==> bash-unit_2.3.3.orig.tar.gz: bash_unit-2.3.3/CONTRIBUTING.md <==
**bash unit testing enterprise edition framework for professionals ![bash_unit](img/bu_50.png)**

If you like bash_unit and want to contribute, you can do so in one of the
following ways (order might matter).

# Spread the word

Talking about bash_unit is a very welcomed contribution.

Share your success with bash_unit on your blog, twitter, stackoverflow...

Nice words to share your experience with bash_unit is always appreciated.
If you want to say something nice about bash_unit but can not think of a 
place for that right now, just add a comment to
[issue #37](https://github.com/bash-unit/bash_unit/issues/37).

Starring the project is also appreciated.

# Suggest improvements

When you see something that is not working with bash_unit, or if you feel
something is missing, open an
[issue](https://github.com/bash-unit/bash_unit/issues).

Opening issues helps improving bash_unit.

# Contribute code

If you use a tool like bash_unit, odds are high that you already heard
about software development. Just code the improvement you have in mind
and create a pull-request.

You can contribute with new features you think are missing but you can
also find inspiration with the
[open issues](https://github.com/bash-unit/bash_unit/issues) of bash_unit.

See [how to contribute code](CONTRIBUTING_CODE.md).

# Donate

bash_unit is free software I develop during my (not so) free time. If you feel
bash_unit is helpful enough to you that you want to compensate for some of
the time spent developing or promoting it, you can contribute with your money
on liberapay:

[![liberapay](https://liberapay.com/assets/widgets/donate.svg)](https://liberapay.com/bash_unit/donate)
